@@ -96,7 +96,8 @@ public class HzDovecotPushClusterLock extends AbstractDovecotPushClusterLock {
             return hzInstance.getMap(mapName);
         } catch (HazelcastInstanceNotActiveException e) {
             handleNotActiveException(e);
-            throw PushExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+            // Obviously Hazelcast is absent
+            return null;
         } catch (HazelcastException e) {
             throw PushExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         } catch (RuntimeException e) {
@@ -129,6 +130,10 @@ public class HzDovecotPushClusterLock extends AbstractDovecotPushClusterLock {
 
         String key = generateKey(sessionInfo);
         IMap<String, String> map = map(hzInstance);
+        if (null == map) {
+            // Hazelcast is absent
+            return true;
+        }
 
         long now = System.nanoTime();
         String previous = map.putIfAbsent(key, generateValue(now, sessionInfo));
@@ -158,7 +163,13 @@ public class HzDovecotPushClusterLock extends AbstractDovecotPushClusterLock {
             throw ServiceExceptionCode.absentService(HazelcastInstance.class);
         }
 
-        map(hzInstance).put(generateKey(sessionInfo), generateValue(System.nanoTime(), sessionInfo));
+        IMap<String, String> map = map(hzInstance);
+        if (null == map) {
+            // Hazelcast is absent
+            return;
+        }
+
+        map.put(generateKey(sessionInfo), generateValue(System.nanoTime(), sessionInfo));
     }
 
     @Override
@@ -171,7 +182,13 @@ public class HzDovecotPushClusterLock extends AbstractDovecotPushClusterLock {
             throw ServiceExceptionCode.absentService(HazelcastInstance.class);
         }
 
-        map(hzInstance).remove(generateKey(sessionInfo));
+        IMap<String, String> map = map(hzInstance);
+        if (null == map) {
+            // Hazelcast is absent
+            return;
+        }
+
+        map.remove(generateKey(sessionInfo));
     }
 
 }
